pub struct ResourceEntities(/* private fields */);Expand description
A cache that links each ComponentId from a resource to the corresponding entity.
Implementations
Sourceimpl ResourceEntities
impl ResourceEntities
Sourcepub fn iter(&self) -> impl Iterator<Item = (ComponentId, Entity)>
pub fn iter(&self) -> impl Iterator<Item = (ComponentId, Entity)>
Returns an iterator over all registered resource components and their corresponding entity.
This must scan the entire array of components to find non-empty values, which may be slow even if there are few resources.
Sourcepub fn get(&self, id: ComponentId) -> Option<Entity>
pub fn get(&self, id: ComponentId) -> Option<Entity>
Returns the entity for the given resource component, or None if there is no entity.